/*
 * MakerBotWatch.cpp
 * 
 * MakerbotWatch code modifier for reversed inner LEDs
 */
 
#include "MakerBotWatch.h"
#include "wiring.h"
 
MakerBotWatch::MakerBotWatch()
{
    pinMode(SPEAKER, OUTPUT);
    pinMode(BUTTON1, INPUT);
    pinMode(BUTTON2, INPUT);
    pinMode(BUTTON3, INPUT);
    clear();
}
 
void MakerBotWatch::clear()
{
    mHoursRow = mHoursCol = - 1;
    mMinutesRow = mMinutesCol = -1;
 
    for (int i = COL0; i <= ROW5; ++i) {
    pinMode(i, INPUT);
        digitalWrite(i, LOW);
    }
}
 
void MakerBotWatch::lightLED(int8_t rowNum, int8_t colNum)
{
#ifdef RESERVED_INNER_LEDS
    if (colNum == COL0 || colNum == COL1) {
    int8_t temp = rowNum;
    rowNum = colNum;
    colNum = temp;
    }
#endif
    digitalWrite(rowNum, HIGH);
    pinMode(rowNum, OUTPUT);
    digitalWrite(colNum, LOW);
    pinMode(colNum, OUTPUT);
}
 
void MakerBotWatch::unlightLED(int8_t rowNum, int8_t colNum)
{
    pinMode(rowNum, INPUT);
    digitalWrite(rowNum, LOW);
    pinMode(colNum, INPUT);
    digitalWrite(colNum, LOW);
}
 
void MakerBotWatch::setTime(int8_t hours, int8_t minutes)
{
	mMinutesOnes = minutes % 5;
    minutes = minutes / 5;
    mMinutesRow = (minutes % 6) + ROW0;
    mMinutesCol = (minutes / 6) + COL2;
 
    mHoursRow = (hours % 6) + ROW0;
    mHoursCol = (hours / 6) + COL0;
}
 
/* this method is suitable for calling in loop().  It shows the
 * minute and hours LEDs for 3ms, for a total of 9ms (2 minutes). If you do
 * nothing but call this, the LEDs will have a 30% duty cycle with a
 * frequency of 100Hz. */
void MakerBotWatch::showTime()
{
    if(mMinutesOnes>0)
	{
	    if(mMinutesOnes>=1)
            lightLED(LED_D);
        if(mMinutesOnes>=2)
            lightLED(LED_C);
        if(mMinutesOnes>=3)
            lightLED(LED_B);
        if(mMinutesOnes>=4)
            lightLED(LED_A);
        delay(3);
        if(mMinutesOnes>=1)
            unlightLED(LED_D);
        if(mMinutesOnes>=2)
            unlightLED(LED_C);
        if(mMinutesOnes>=3)
            unlightLED(LED_B);
        if(mMinutesOnes>=4)
            unlightLED(LED_A);
	}
	
    lightLED(mMinutesRow, mMinutesCol);
    delay(3);
    unlightLED(mMinutesRow, mMinutesCol);
 
    lightLED(mHoursRow, mHoursCol);
    delay(3);
    unlightLED(mHoursRow, mHoursCol);
}